@@ -205,6 +205,15 @@ class Univariate:
         return z_score
 
     def cumulative_distribution(self):
+        """
+        Cumulative Frequency Interpretation:
+        https://www150.statcan.gc.ca/n1/edu/power-pouvoir/ch10/5214862-eng.htm
+        http://www.statlit.org/pdf/2009WinklerASA.pdf
+
+        Kernel Density Plot Interpretation:
+        http://www.statlit.org/pdf/2009WinklerASA.pdf
+        :return:
+        """
         cumulative_frequency = []
         cf = 0
         for i in self.unique_value_frequency():
@@ -230,21 +239,22 @@ class Univariate:
         sns.set(style="white", palette="muted", color_codes=True)
 
         f, axes = plt.subplots(2, 2, figsize=(16, 10), sharex=True)
-        # sns.despine(left=True)
 
         # Plot a simple histogram with binsize determined automatically
+        plt.title("Basic Histogram")
         sns.distplot(self.data, kde=False, color="b", ax=axes[0, 0])
 
         # Plot a kernel density estimate and rug plot
+        plt.title("Kernel Density Estimate With Rug")
         sns.distplot(self.data, hist=False, rug=True, color="r", ax=axes[0, 1])
 
         # Plot a filled kernel density estimate
+        plt.title("Kernel Density Estimate Filled")
         sns.distplot(self.data, hist=False, color="g", kde_kws={"shade": True}, ax=axes[1, 0])
 
         # Plot a histogram and kernel density estimate
         sns.distplot(self.data, color="m", ax=axes[1, 1])
-
-        plt.title("Kernel Density Function Plots")
+        plt.title("Kernel Density Estimate VS Histogram")
         plt.setp(axes, yticks=[])
         plt.tight_layout()
 
@@ -305,6 +315,11 @@ class Univariate:
         return means_plot
 
     def mean_vs_median(self):
+        """
+        Useful notes on mean vs median
+        https://www.diffen.com/difference/Mean_vs_Median
+        :return: bar plot comparision of median vs mean
+        """
         fig2 = plt.figure(constrained_layout=True, figsize=(16, 10))
         mvm = [self.mean(), self.median()]
         mvm_plot = plt.bar(x=['Mean', 'Mode'], height=mvm)
@@ -380,27 +395,38 @@ class Univariate:
         Skew & Kurtosis
         http://davidmlane.com/hyperstat/desc_univ.html
 
-        :return:
+        Variance
+        https://mathbitsnotebook.com/Algebra1/StatisticsData/STSD.html
 
+        Standard Deviation
+        https://mathbitsnotebook.com/Algebra1/StatisticsData/STSD.html
+
+        Simple Usage:
         x = [1, 2, 3, 4, 5, 6, 7, 8, 9, 2, 3, 4, 5, 6, 7, 8, 3, 4, 5, 6, 7, 4, 5, 6, 5, 6, 5, 6, 3, 8, 5, 4, 3, 9, 10]
         x_summary = Univariate(data=x)
         x_summary.descriptive_summary()
+
+        :return: A descriptive summary report
+
         '''
         print("----------------- \n Descriptive Summary \n -----------------")
+        print("\nThe descriptive summary is designed to capture variance in a single variable. The core measures "
+              "focus on central tendency and dispersion. This report can be used on its own to provide a descriptive "
+              "overview of the variable.")
         self.mean_plots()
         print("Arithmetic Mean: ")
         print("The mean is the only single number for which the residuals (deviations from the estimate) sum to "
               "zero. If it is required to use a single number as a typical value for a set of known numbers. The "
               "arithmetic mean of this variable is: ", round(self.mean(), 3))
 
-        print("\nGeometric Mean: \n  indicates the central tendency or typical value of a set of numbers by using the "
-              "product of their values. The geometric mean applies only to positive numbers. the geometric mean is "
-              "only correct mean when averaging normalized results; that is, results that are presented as ratios to "
-              "reference values. The geometric mean of this variable is: ", self.geometric_mean())
+        print("\nGeometric Mean: \n  The geometric mean indicates the central tendency or typical value of a set of "
+              "numbers by using the product of their values. The geometric mean applies only to positive numbers. the "
+              "geometric mean is only correct mean when averaging normalized results; that is, results that are "
+              "presented as ratios to reference values. The geometric mean of this variable is: ", self.geometric_mean())
 
         print("\nHarmonic Mean: \n The harmonic mean can be expressed as the reciprocal of the arithmetic mean of "
               "the reciprocals of the given set of observations. For all positive data sets containing at least one "
-              "pair of nonequal values, the harmonic mean is always the least of the three means,[1] while the "
+              "pair of non-equal values, the harmonic mean is always the least of the three means,[1] while the "
               "arithmetic mean is always the greatest of the three and the geometric mean is always in between. Since "
               "the harmonic mean of a list of numbers tends strongly toward the least elements of the list, "
               "it tends (compared to the arithmetic mean) to mitigate the impact of large outliers and aggravate the "
@@ -421,9 +447,10 @@ class Univariate:
         print("\nMedian: \n The median is less sensitive to extreme scores than the mean and this makes it a better "
               "measure than the mean for highly skewed distributions. ", self.median())
 
-        print("Mean, Median & Mode Comparison \n The mean, median, and mode are equal in symmetric distributions. The "
+        print("\nMean - Median Comparison:\nThe mean and median are equal in symmetric distributions. The "
               "mean is typically higher than the median in positively skewed distributions and lower than the median "
-              "in negatively skewed distributions.")
+              "in negatively skewed distributions. If you have disproportionally large or small numbers in your dataset"
+              "that are not errors it could be beneficial to use the median as a measure of central tendency")
 
         self.mean_vs_median()
         plt.show()
@@ -435,18 +462,38 @@ class Univariate:
               "the same kurtosis as the normal distribution is called mesokurtic. Variable kurtosis is: ",
               self.kurtosis())
 
-        print("Frequency\nNumber of Unique Values: ", self.unique_value_count(), "\n")
+        print("\nFrequency:\nThe number of unique values in the data set: ", self.unique_value_count(), "\n")
 
-        print("The cumulative frequency distribution and related kernel density estimate is shown below:")
+        print("Cumulative frequency is used to determine the number of observations that lie above or below a "
+              "particular value in a data set. The last value will always be equal to the total sum of the values\n"
+              "The kernel density plot visualises the distribution of data in a smoothed manner preventing individual"
+              "numbers from influencing the shape of the distribution significantly. It can be used in conjunction with"
+              "the skew and kurtosis statistics calculated earlier to identify over arching distribution of values from"
+              "the center of the data set.\n"
+              "The cumulative frequency distribution and related kernel density estimate is shown below:")
         self.cumulative_distribution()
         plt.show()
 
-        print("\nThe variance is computed as the average squared deviation of each number from its mean. The variance "
+        print("Variance:\nVariance measures how spread out a data set is. A variance of 0 indicates that all of the"
+              "values are identical. A small variance indicates that the data points tend to be very close to the mean"
+              "and a high variance indicates that the values tend to be far away from the mean. It is important to note"
+              "that the variance value is not the same unit of measure as the original dataset, rather it is the square"
+              "of that unit of measure."
+              "\nThe variance is computed as the average squared deviation of each number from its mean. The variance "
               "for this variable is: ", self.variance())
+
+        print("\nThe standard deviation is the square root of the variance. This variable has a standard deviation of ",
+              self.standard_deviation(),
+              "It represents a typical deviation from the mean. It is a popular measure of variability because it" 
+              "returns to the original units of measure of the data set.")
         self.probability_density_function()
         plt.show()
 
-        print("A range of histograms with different bin calculations can be found below:")
+        print("Histograms are a useful way to understand how data is grouped together. The number of bins is a key"
+              "determining factor in understanding how a histogram represents a data distribution. The histograms below"
+              "provide a range of different bins to provide a more complete overview of the data preventing"
+              "interpretation bias that occur with one plot."
+              "A range of histograms with different bin calculations can be found below:")
         self.histogram()
         plt.show()
 
@@ -457,11 +504,8 @@ class Univariate:
         print("The value at the 70th percentile is: ", self.percentile_70())
         print("The interquartile range is ", self.interquartile_range())
 
-        print("\nThe standard deviation is the square root of the variance. This variable has a standard deviation of ",
-              self.standard_deviation())
-
-        print(
-            "The below grid of plots includes additional frequency distributions based on unique values, a box plot and a squared difference plot ")
+        print("The below grid of plots includes additional frequency distributions based on unique values, a box plot "
+              "and a squared difference plot ")
 
         self.unique_value_distribution()
         plt.show()
